==> haskell-basement-0.0.12-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-basement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 basement
version:              0.0.12
visibility:           public
id:                   basement-0.0.12-Ha8dnCjMGwLHmraNHnqo8U
key:                  basement-0.0.12-Ha8dnCjMGwLHmraNHnqo8U
license:              BSD-3-Clause
copyright:
    2015-2017 Vincent Hanquez <vincent@snarc.org>
    , 2017-2018 Foundation Maintainers

maintainer:           vincent@snarc.org
homepage:             https://github.com/haskell-foundation/foundation#readme
synopsis:             Foundation scrap box of array & string
description:          Foundation most basic primitives without any dependencies
category:             Web
abi:                  a4c3dd913490b4d9a4c52f749caa7c2a
exposed:              True
exposed-modules:
    Basement.Alg.XorShift Basement.Base16 Basement.Bindings.Memory
    Basement.Bits Basement.Block Basement.Block.Builder
    Basement.Block.Mutable Basement.BlockN Basement.Bounded
    Basement.BoxedArray Basement.Cast Basement.Compat.AMP
    Basement.Compat.Base Basement.Compat.Bifunctor
    Basement.Compat.C.Types Basement.Compat.CallStack
    Basement.Compat.ExtList Basement.Compat.Identity
    Basement.Compat.IsList Basement.Compat.MonadTrans
    Basement.Compat.Natural Basement.Compat.NumLiteral
    Basement.Compat.PrimTypes Basement.Compat.Primitive
    Basement.Compat.Semigroup Basement.Compat.Typeable
    Basement.Endianness Basement.Environment Basement.Exception
    Basement.FinalPtr Basement.Floating Basement.From Basement.Imports
    Basement.IntegralConv Basement.Monad Basement.MutableBuilder
    Basement.Nat Basement.NonEmpty Basement.NormalForm
    Basement.Numerical.Additive Basement.Numerical.Multiplicative
    Basement.Numerical.Number Basement.Numerical.Subtractive
    Basement.PrimType Basement.Sized.Block Basement.Sized.List
    Basement.Sized.UVect Basement.Sized.Vect Basement.String
    Basement.String.Builder Basement.Terminal Basement.Terminal.ANSI
    Basement.These Basement.Types.AsciiString Basement.Types.Char7
    Basement.Types.CharUTF8 Basement.Types.OffsetSize
    Basement.Types.Ptr Basement.Types.Word128 Basement.Types.Word256
    Basement.UArray Basement.UArray.Mutable

hidden-modules:
    Basement.Error Basement.Show Basement.Runtime Basement.Alg.Class
    Basement.Alg.Mutable Basement.Alg.PrimArray Basement.Alg.UTF8
    Basement.Alg.String Basement.Numerical.Conversion
    Basement.Block.Base Basement.UTF8.Base Basement.UTF8.Helper
    Basement.UTF8.Table Basement.UTF8.Types Basement.UArray.Base
    Basement.String.CaseMapping Basement.String.Encoding.Encoding
    Basement.String.Encoding.UTF16 Basement.String.Encoding.UTF32
    Basement.String.Encoding.ASCII7 Basement.String.Encoding.ISO_8859_1
    Basement.Terminal.Size

import-dirs:          /usr/lib/ghc-9.0.2/site-local/basement-0.0.12
library-dirs:         /usr/lib/ghc-9.0.2/site-local/basement-0.0.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/basement-0.0.12
hs-libraries:         HSbasement-0.0.12-Ha8dnCjMGwLHmraNHnqo8U
depends:              base-4.15.1.0 ghc-prim-0.7.0
haddock-interfaces:   /usr/share/doc/haskell-basement/html/basement.haddock
haddock-html:         /usr/share/doc/haskell-basement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-basement-0.0.13-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-basement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 basement
version:              0.0.13
visibility:           public
id:                   basement-0.0.13-Lm6jF51RLME84RnuvMeGw6
key:                  basement-0.0.13-Lm6jF51RLME84RnuvMeGw6
license:              BSD-3-Clause
copyright:
    2015-2017 Vincent Hanquez <vincent@snarc.org>
    , 2017-2018 Foundation Maintainers

maintainer:           vincent@snarc.org
homepage:             https://github.com/haskell-foundation/foundation#readme
synopsis:             Foundation scrap box of array & string
description:          Foundation most basic primitives without any dependencies
category:             Web
abi:                  9c3aa460537656dd4cbf8c5ca7eed900
exposed:              True
exposed-modules:
    Basement.Alg.XorShift Basement.Base16 Basement.Bindings.Memory
    Basement.Bits Basement.Block Basement.Block.Builder
    Basement.Block.Mutable Basement.BlockN Basement.Bounded
    Basement.BoxedArray Basement.Cast Basement.Compat.AMP
    Basement.Compat.Base Basement.Compat.Bifunctor
    Basement.Compat.C.Types Basement.Compat.CallStack
    Basement.Compat.ExtList Basement.Compat.Identity
    Basement.Compat.IsList Basement.Compat.MonadTrans
    Basement.Compat.Natural Basement.Compat.NumLiteral
    Basement.Compat.PrimTypes Basement.Compat.Primitive
    Basement.Compat.Semigroup Basement.Compat.Typeable
    Basement.Endianness Basement.Environment Basement.Exception
    Basement.FinalPtr Basement.Floating Basement.From Basement.Imports
    Basement.IntegralConv Basement.Monad Basement.MutableBuilder
    Basement.Nat Basement.NonEmpty Basement.NormalForm
    Basement.Numerical.Additive Basement.Numerical.Multiplicative
    Basement.Numerical.Number Basement.Numerical.Subtractive
    Basement.PrimType Basement.Sized.Block Basement.Sized.List
    Basement.Sized.UVect Basement.Sized.Vect Basement.String
    Basement.String.Builder Basement.Terminal Basement.Terminal.ANSI
    Basement.These Basement.Types.AsciiString Basement.Types.Char7
    Basement.Types.CharUTF8 Basement.Types.OffsetSize
    Basement.Types.Ptr Basement.Types.Word128 Basement.Types.Word256
    Basement.UArray Basement.UArray.Mutable

hidden-modules:
    Basement.Error Basement.Show Basement.Runtime Basement.Alg.Class
    Basement.Alg.Mutable Basement.Alg.PrimArray Basement.Alg.UTF8
    Basement.Alg.String Basement.Numerical.Conversion
    Basement.Block.Base Basement.UTF8.Base Basement.UTF8.Helper
    Basement.UTF8.Table Basement.UTF8.Types Basement.UArray.Base
    Basement.String.CaseMapping Basement.String.Encoding.Encoding
    Basement.String.Encoding.UTF16 Basement.String.Encoding.UTF32
    Basement.String.Encoding.ASCII7 Basement.String.Encoding.ISO_8859_1
    Basement.Terminal.Size

import-dirs:          /usr/lib/ghc-9.0.2/site-local/basement-0.0.13
library-dirs:         /usr/lib/ghc-9.0.2/site-local/basement-0.0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/basement-0.0.13
hs-libraries:         HSbasement-0.0.13-Lm6jF51RLME84RnuvMeGw6
depends:              base-4.15.1.0 ghc-prim-0.7.0
haddock-interfaces:   /usr/share/doc/haskell-basement/html/basement.haddock
haddock-html:         /usr/share/doc/haskell-basement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
